# Upload CSV file and perform CRUD operations on it.
Upload a csv file, it shows the table formation for that file in browser.
You can perform CRUD operations over there using different buttons, it will connect the table with db.

## Installation
pip install csv_db_package

## License 
© 2022 Ankita Liya

This repository is licensed under the MIT license. See LICENSE for details.

